{% extends "admin/base_site.html" %}
{% load i18n %}

{% block extrastyle %}{% load adminmedia %}{{ block.super }}<link rel="stylesheet" type="text/css" href="{% admin_media_prefix %}css/login.css" />{% endblock %}

{% block bodyclass %}login{% endblock %}

{% block content_title %}{% endblock %}

{% block breadcrumbs %}{% endblock %}

{% block content %}
{% if form.non_field_errors %}
<div class="errornote">{{ form.non_field_errors }}</div>
{% endif %}
<div id="content-main">
<form method="post" id="login-form">
  {% csrf_token %}
  <div class="form-row">
	<label for="id_{{ form.email.name }}">{{ form.email.label }}</label> {{ form.email }} {{ form.errors.email }}
  </div>
  <div class="form-row">
    <label for="id_{{ form.password.name }}">{{ form.password.label }}</label> {{ form.password }} {{ form.errors.password }}
  </div>
  <div class="form-row">
	<label for="id_{{ form.remember.name }}">{{ form.remember.label }}</label> {{ form.remember }} {{ form.errors.remember }}
  </div>
  <div class="submit-row">
    <label>&nbsp;</label><input type="submit" value="{% trans 'Log in' %}"  />
  </div>
</form>

<script type="text/javascript">
document.getElementById('id_email').focus()
</script>
{% endblock content %}
